@@ -57,7 +57,7 @@ from .hooks import ProjectHookManager  # noqa: F401
 from .integrations import ProjectIntegrationManager, ProjectServiceManager  # noqa: F401
 from .invitations import ProjectInvitationManager  # noqa: F401
 from .issues import ProjectIssueManager  # noqa: F401
-from .iterations import GroupIterationManager  # noqa: F401
+from .iterations import ProjectIterationManager  # noqa: F401
 from .jobs import ProjectJobManager  # noqa: F401
 from .labels import ProjectLabelManager  # noqa: F401
 from .members import ProjectMemberAllManager, ProjectMemberManager  # noqa: F401
@@ -81,7 +81,9 @@ from .project_access_tokens import ProjectAccessTokenManager  # noqa: F401
 from .push_rules import ProjectPushRulesManager  # noqa: F401
 from .releases import ProjectReleaseManager  # noqa: F401
 from .repositories import RepositoryMixin
+from .resource_groups import ProjectResourceGroupManager
 from .runners import ProjectRunnerManager  # noqa: F401
+from .secure_files import ProjectSecureFileManager  # noqa: F401
 from .snippets import ProjectSnippetManager  # noqa: F401
 from .statistics import (  # noqa: F401
     ProjectAdditionalStatisticsManager,
@@ -155,7 +157,7 @@ class ProjectGroupManager(ListMixin, RESTManager):
 
 
 class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTObject):
-    _repr_attr = "path"
+    _repr_attr = "path_with_namespace"
 
     access_tokens: ProjectAccessTokenManager
     accessrequests: ProjectAccessRequestManager
@@ -186,7 +188,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
     invitations: ProjectInvitationManager
     issues: ProjectIssueManager
     issues_statistics: ProjectIssuesStatisticsManager
-    iterations: GroupIterationManager
+    iterations: ProjectIterationManager
     jobs: ProjectJobManager
     keys: ProjectKeyManager
     labels: ProjectLabelManager
@@ -206,9 +208,11 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
     protectedtags: ProjectProtectedTagManager
     pushrules: ProjectPushRulesManager
     releases: ProjectReleaseManager
+    resource_groups: ProjectResourceGroupManager
     remote_mirrors: "ProjectRemoteMirrorManager"
     repositories: ProjectRegistryRepositoryManager
     runners: ProjectRunnerManager
+    secure_files: ProjectSecureFileManager
     services: ProjectServiceManager
     snippets: ProjectSnippetManager
     storage: "ProjectStorageManager"
@@ -504,7 +508,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
         self,
         wiki: bool = False,
         streamed: bool = False,
-        action: Optional[Callable] = None,
+        action: Optional[Callable[[bytes], None]] = None,
         chunk_size: int = 1024,
         *,
         iterator: bool = False,
@@ -579,6 +583,29 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
         path = f"/projects/{self.encoded_id}/mirror/pull"
         self.manager.gitlab.http_post(path, **kwargs)
 
+    @cli.register_custom_action("Project")
+    @exc.on_http_error(exc.GitlabGetError)
+    def mirror_pull_details(self, **kwargs: Any) -> Dict[str, Any]:
+        """Get a project's pull mirror details.
+
+        Introduced in GitLab 15.5.
+
+        Args:
+            **kwargs: Extra options to send to the server (e.g. sudo)
+
+        Raises:
+            GitlabAuthenticationError: If authentication is not correct
+            GitlabGetError: If the server failed to perform the request
+
+        Returns:
+            dict of the parsed json returned by the server
+        """
+        path = f"/projects/{self.encoded_id}/mirror/pull"
+        result = self.manager.gitlab.http_get(path, **kwargs)
+        if TYPE_CHECKING:
+            assert isinstance(result, dict)
+        return result
+
     @cli.register_custom_action("Project", ("to_namespace",))
     @exc.on_http_error(exc.GitlabTransferProjectError)
     def transfer(self, to_namespace: Union[int, str], **kwargs: Any) -> None:
@@ -640,6 +667,7 @@ class ProjectManager(CRUDMixin, RESTManager):
             "name",
             "path",
             "allow_merge_on_skipped_pipeline",
+            "only_allow_merge_if_all_status_checks_passed",
             "analytics_access_level",
             "approvals_before_merge",
             "auto_cancel_pending_pipelines",
@@ -653,6 +681,7 @@ class ProjectManager(CRUDMixin, RESTManager):
             "builds_access_level",
             "ci_config_path",
             "container_expiration_policy_attributes",
+            "container_registry_access_level",
             "container_registry_enabled",
             "default_branch",
             "description",
@@ -681,11 +710,17 @@ class ProjectManager(CRUDMixin, RESTManager):
             "requirements_access_level",
             "printing_merge_request_link_enabled",
             "public_builds",
+            "releases_access_level",
+            "environments_access_level",
+            "feature_flags_access_level",
+            "infrastructure_access_level",
+            "monitor_access_level",
             "remove_source_branch_after_merge",
             "repository_access_level",
             "repository_storage",
             "request_access_enabled",
             "resolve_outdated_diff_discussions",
+            "security_and_compliance_access_level",
             "shared_runners_enabled",
             "show_default_award_emojis",
             "snippets_access_level",
@@ -706,6 +741,7 @@ class ProjectManager(CRUDMixin, RESTManager):
     _update_attrs = RequiredOptional(
         optional=(
             "allow_merge_on_skipped_pipeline",
+            "only_allow_merge_if_all_status_checks_passed",
             "analytics_access_level",
             "approvals_before_merge",
             "auto_cancel_pending_pipelines",
@@ -720,26 +756,36 @@ class ProjectManager(CRUDMixin, RESTManager):
             "ci_config_path",
             "ci_default_git_depth",
             "ci_forward_deployment_enabled",
+            "ci_allow_fork_pipelines_to_run_in_parent_project",
+            "ci_separated_caches",
             "container_expiration_policy_attributes",
+            "container_registry_access_level",
             "container_registry_enabled",
             "default_branch",
             "description",
             "emails_disabled",
+            "enforce_auth_checks_on_uploads",
             "external_authorization_classification_label",
             "forking_access_level",
             "import_url",
             "issues_access_level",
             "issues_enabled",
+            "issues_template",
             "jobs_enabled",
+            "keep_latest_artifact",
             "lfs_enabled",
+            "merge_commit_template",
             "merge_method",
             "merge_pipelines_enabled",
             "merge_requests_access_level",
             "merge_requests_enabled",
+            "merge_requests_template",
+            "merge_trains_enabled",
             "mirror_overwrites_diverged_branches",
             "mirror_trigger_builds",
             "mirror_user_id",
             "mirror",
+            "mr_default_target_self",
             "name",
             "operations_access_level",
             "only_allow_merge_if_all_discussions_are_resolved",
@@ -751,16 +797,24 @@ class ProjectManager(CRUDMixin, RESTManager):
             "restrict_user_defined_variables",
             "path",
             "public_builds",
+            "releases_access_level",
+            "environments_access_level",
+            "feature_flags_access_level",
+            "infrastructure_access_level",
+            "monitor_access_level",
             "remove_source_branch_after_merge",
             "repository_access_level",
             "repository_storage",
             "request_access_enabled",
             "resolve_outdated_diff_discussions",
+            "security_and_compliance_access_level",
             "service_desk_enabled",
             "shared_runners_enabled",
             "show_default_award_emojis",
             "snippets_access_level",
             "snippets_enabled",
+            "issue_branch_template",
+            "squash_commit_template",
             "squash_option",
             "suggestion_commit_message",
             "tag_list",
@@ -768,8 +822,6 @@ class ProjectManager(CRUDMixin, RESTManager):
             "visibility",
             "wiki_access_level",
             "wiki_enabled",
-            "issues_template",
-            "merge_requests_template",
         ),
     )
     _list_filters = (
@@ -807,6 +859,7 @@ class ProjectManager(CRUDMixin, RESTManager):
     def get(self, id: Union[str, int], lazy: bool = False, **kwargs: Any) -> Project:
         return cast(Project, super().get(id=id, lazy=lazy, **kwargs))
 
+    @exc.on_http_error(exc.GitlabImportError)
     def import_project(
         self,
         file: str,
@@ -822,6 +875,8 @@ class ProjectManager(CRUDMixin, RESTManager):
         Args:
             file: Data or file object containing the project
             path: Name and path for the new project
+            name: The name of the project to import. If not provided,
+                defaults to the path of the project.
             namespace: The ID or path of the namespace that the project
                 will be imported to
             overwrite: If True overwrite an existing project with the
@@ -831,7 +886,7 @@ class ProjectManager(CRUDMixin, RESTManager):
 
         Raises:
             GitlabAuthenticationError: If authentication is not correct
-            GitlabListError: If the server failed to perform the request
+            GitlabImportError: If the server failed to perform the request
 
         Returns:
             A representation of the import status.
@@ -849,6 +904,110 @@ class ProjectManager(CRUDMixin, RESTManager):
             "/projects/import", post_data=data, files=files, **kwargs
         )
 
+    @exc.on_http_error(exc.GitlabImportError)
+    def remote_import(
+        self,
+        url: str,
+        path: str,
+        name: Optional[str] = None,
+        namespace: Optional[str] = None,
+        overwrite: bool = False,
+        override_params: Optional[Dict[str, Any]] = None,
+        **kwargs: Any,
+    ) -> Union[Dict[str, Any], requests.Response]:
+        """Import a project from an archive file stored on a remote URL.
+
+        Args:
+            url: URL for the file containing the project data to import
+            path: Name and path for the new project
+            name: The name of the project to import. If not provided,
+                defaults to the path of the project.
+            namespace: The ID or path of the namespace that the project
+                will be imported to
+            overwrite: If True overwrite an existing project with the
+                same path
+            override_params: Set the specific settings for the project
+            **kwargs: Extra options to send to the server (e.g. sudo)
+
+        Raises:
+            GitlabAuthenticationError: If authentication is not correct
+            GitlabImportError: If the server failed to perform the request
+
+        Returns:
+            A representation of the import status.
+        """
+        data = {"path": path, "overwrite": str(overwrite), "url": url}
+        if override_params:
+            for k, v in override_params.items():
+                data[f"override_params[{k}]"] = v
+        if name is not None:
+            data["name"] = name
+        if namespace:
+            data["namespace"] = namespace
+        return self.gitlab.http_post(
+            "/projects/remote-import", post_data=data, **kwargs
+        )
+
+    @exc.on_http_error(exc.GitlabImportError)
+    def remote_import_s3(
+        self,
+        path: str,
+        region: str,
+        bucket_name: str,
+        file_key: str,
+        access_key_id: str,
+        secret_access_key: str,
+        name: Optional[str] = None,
+        namespace: Optional[str] = None,
+        overwrite: bool = False,
+        override_params: Optional[Dict[str, Any]] = None,
+        **kwargs: Any,
+    ) -> Union[Dict[str, Any], requests.Response]:
+        """Import a project from an archive file stored on AWS S3.
+
+        Args:
+            region: AWS S3 region name where the file is stored
+            bucket_name: AWS S3 bucket name where the file is stored
+            file_key: AWS S3 file key to identify the file.
+            access_key_id: AWS S3 access key ID.
+            secret_access_key: AWS S3 secret access key.
+            path: Name and path for the new project
+            name: The name of the project to import. If not provided,
+                defaults to the path of the project.
+            namespace: The ID or path of the namespace that the project
+                will be imported to
+            overwrite: If True overwrite an existing project with the
+                same path
+            override_params: Set the specific settings for the project
+            **kwargs: Extra options to send to the server (e.g. sudo)
+
+        Raises:
+            GitlabAuthenticationError: If authentication is not correct
+            GitlabImportError: If the server failed to perform the request
+
+        Returns:
+            A representation of the import status.
+        """
+        data = {
+            "region": region,
+            "bucket_name": bucket_name,
+            "file_key": file_key,
+            "access_key_id": access_key_id,
+            "secret_access_key": secret_access_key,
+            "path": path,
+            "overwrite": str(overwrite),
+        }
+        if override_params:
+            for k, v in override_params.items():
+                data[f"override_params[{k}]"] = v
+        if name is not None:
+            data["name"] = name
+        if namespace:
+            data["namespace"] = namespace
+        return self.gitlab.http_post(
+            "/projects/remote-import-s3", post_data=data, **kwargs
+        )
+
     def import_bitbucket_server(
         self,
         bitbucket_server_url: str,
